/*****************************************************************************
 * Copyright (C) The Apache Software Foundation. All rights reserved.        *
 * ------------------------------------------------------------------------- *
 * This software is published under the terms of the Apache Software License *
 * version 1.1, a copy of which has been included with this distribution in  *
 * the LICENSE file.                                                         *
 *****************************************************************************/

package org.apache.batik.bridge;

import org.apache.batik.gvt.GraphicsNode;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

/**
 * This class is responsible on building a GVT tree using an SVG document.
 *
 * @author <a href="mailto:Thierry.Kormann@sophia.inria.fr">Thierry Kormann</a>
 * @version $Id: GVTBuilder.java,v 1.2 2000/10/25 18:16:12 vhardy Exp $
 */
public interface GVTBuilder {

    /**
     * Builds a GVT tree using the specified context and SVG document.
     * @param ctx the context to use
     * @param svgDocument the DOM tree that represents an SVG document
     */
    GraphicsNode build(BridgeContext ctx, Document svgDocument);

    /**
     * Builds a GVT tree using the specified context and SVG element
     * @param ctx the context to use
     * @param element element for which a GVT representation should be built
     */
    GraphicsNode build(BridgeContext ctx, Element element);

}
