/*****************************************************************************
 * Copyright (C) The Apache Software Foundation. All rights reserved.        *
 * ------------------------------------------------------------------------- *
 * This software is published under the terms of the Apache Software License *
 * version 1.1, a copy of which has been included with this distribution in  *
 * the LICENSE file.                                                         *
 *****************************************************************************/

package org.apache.batik.dom.svg;

import org.w3c.dom.DOMException;
import org.w3c.dom.Element;
import org.w3c.dom.svg.SVGAnimatedNumber;

/**
 * This class implements {@link org.w3c.dom.svg.SVGAnimatedNumber}.
 *
 * @author <a href="mailto:stephane@hillion.org">Stephane Hillion</a>
 * @version $Id: SVGOMAnimatedNumber.java,v 1.1 2000/10/29 15:28:02 hillion Exp $
 */
public class SVGOMAnimatedNumber implements SVGAnimatedNumber {
    /**
     * The associated element.
     */
    protected Element element;

    /**
     * The associated attribute namespace URI.
     */
    protected String attributeNsURI;

    /**
     * The associated attribute name.
     */
    protected String attributeName;

    /**
     * Creates a new SVGAnimatedNumber object.
     * @param elt The associated element.
     * @param attr The associated attribute name.
     */
    public SVGOMAnimatedNumber(Element elt, String nsURI, String attr) {
	element = elt;
	attributeNsURI = nsURI;
	attributeName = attr;
    }

    /**
     * <b>DOM</b>: Implements {@link
     * org.w3c.dom.svg.SVGAnimatedNumber#getBaseVal()}.
     */
    public float getBaseVal() {
	return Float.parseFloat(element.getAttributeNS(attributeNsURI,
                                                       attributeName));
    }

    /**
     * <b>DOM</b>: Implements {@link
     * org.w3c.dom.svg.SVGAnimatedNumber#getBaseVal()}.
     */
    public void setBaseVal(float baseVal) throws DOMException {
	element.setAttributeNS(attributeNsURI, attributeName,
                               Float.toString(baseVal));
    }

    /**
     * <b>DOM</b>: Implements {@link
     * org.w3c.dom.svg.SVGAnimatedNumber#getAnimVal()}.
     */
    public float getAnimVal() {
	throw new RuntimeException(" !!! TODO: SVGOMAnimatedNumber.getAnimVal()");
    }
}
