/*****************************************************************************
 * Copyright (C) The Apache Software Foundation. All rights reserved.        *
 *---------------------------------------------------------------------------*
 * This software is published under the terms of the Apache Software License *
 * version 1.1, a copy of which has been included with this distribution in  *
 * the LICENSE file.                                                         *
 *****************************************************************************/

package org.apache.batik.refimpl.script.jpython;

import java.io.*;
import java.util.Locale;
import org.apache.batik.script.*;
import org.python.util.*;

/**
 * A simple implementation of <code>Interpreter</code> interface to use
 * JPython python parser.
 * @author <a href="mailto:cjolif@ilog.fr">Christophe Jolif</a>
 * @version $Id: JPythonInterpreter.java,v 1.1.1.1 2000/10/10 18:41:48 hillion Exp $
 */
public class JPythonInterpreter implements org.apache.batik.script.Interpreter {
    private PythonInterpreter interpreter = null;
    
    public JPythonInterpreter() {
        interpreter = new PythonInterpreter();
        // import Java lang package & DOM Level 2 & SVG DOM packages
        /*
        NativeJavaPackage pkg = new NativeJavaPackage("java.lang");
        pkg = new NativeJavaPackage("org.w3c.dom");
        pkg = new NativeJavaPackage("org.w3c.dom.css");
        pkg = new NativeJavaPackage("org.w3c.dom.events");
        pkg = new NativeJavaPackage("org.w3c.dom.smil");
        pkg = new NativeJavaPackage("org.w3c.dom.stylesheets");
        pkg = new NativeJavaPackage("org.w3c.dom.svg");
        pkg = new NativeJavaPackage("org.w3c.dom.views");
        */
    }

    // org.apache.batik.script.Intepreter implementation
    
    public Object evaluate(Reader scriptreader) 
        throws InterpreterException, IOException {
        try {
            // oups jpython doesn't accept reader in its eval method :-(
            StringBuffer sbuffer = new StringBuffer();
            char[] buffer = new char[1024];
            int val = 0;
            while ((val = scriptreader.read(buffer)) != -1) {
                sbuffer.append(buffer,0, val);
            }
            String str = sbuffer.toString();
            interpreter.exec(str);
        } catch (org.python.core.PyException e) {
            e.printStackTrace();
            throw new InterpreterException(e, e.getMessage(), -1, -1);
        } catch (RuntimeException re) {
            throw new InterpreterException(re, re.getMessage(), -1, -1);
        }
        return null;
    }
    
    public void dispose() {
    }
    
    public void bindObject(String name, Object object) {
        interpreter.set(name, object);
    } 
    
    public void setOut(Writer out) {
        interpreter.setOut(out);
    }
    
    // org.apache.batik.i18n.Localizable implementation

    public Locale getLocale() {
        return null;
    }

    public void setLocale(Locale locale) {
    }
    
    public String formatMessage(String key, Object[] args) {
        return null;
    }
}
