/*****************************************************************************
 * Copyright (C) The Apache Software Foundation. All rights reserved.        *
 * ------------------------------------------------------------------------- *
 * This software is published under the terms of the Apache Software License *
 * version 1.1, a copy of which has been included with this distribution in  *
 * the LICENSE file.                                                         *
 *****************************************************************************/

package org.apache.batik.util.awt.svg;

import java.util.Map;
import java.util.Hashtable;
import java.util.Set;
import java.util.HashSet;

import org.w3c.dom.*;

/**
 * Describes an SVG clip
 *
 * @author <a href="mailto:vincent.hardy@eng.sun.com">Vincent Hardy</a>
 * @version $Id: SVGClipDescriptor.java,v 1.1 2000/11/14 22:01:12 vhardy Exp $
 * @see           org.apache.batik.util.awt.svg.GraphicContext
 * @see           org.apache.batik.util.awt.svg.SVGDescriptor
 */
public class SVGClipDescriptor implements SVGDescriptor, SVGSyntax{
    public static final String ERROR_NULL_INPUT = "clipPathValue should not be null";

    private String clipPathValue;
    private Element clipPathDef;

    /**
     * @param clipPathDef definition of a clip path
     * @param attribute value referencing clipPathDef
     */
    public SVGClipDescriptor(String clipPathValue, Element clipPathDef){
        if(clipPathValue == null)
            throw new IllegalArgumentException(ERROR_NULL_INPUT);

        this.clipPathValue = clipPathValue;
        this.clipPathDef = clipPathDef;
    }

    /**
     * @param attrMap if not null, attribute name/value pairs
     *        for this descriptor should be written in this Map.
     *        Otherwise, a new Map will be created and attribute
     *        name/value pairs will be written into it.
     * @return a map containing the SVG attributes needed by the
     *         descriptor.
     */
    public Map getAttributeMap(Map attrMap){
        if(attrMap == null)
            attrMap = new Hashtable();

        attrMap.put(ATTR_CLIP_PATH, clipPathValue);

        return attrMap;
    }


    /**
     * @param defSet if not null, definitions required to provide
     *        targets for the descriptor attribute values will be
     *        copied into defSet. If null, a new Set should be created
     *        and definitions copied into it. The set contains
     *        zero, one or more Elements.
     * @return a set containing Elements that represent the definition
     *         of the descriptor's attribute values
     */
    public Set getDefinitionSet(Set defSet){
        if(defSet == null)
            defSet = new HashSet();

        if(clipPathDef != null)
            defSet.add(clipPathDef);

        return defSet;
    }
}
